<template>
  <AdminLayout>
    <DashboardHeader>
      <DashboardTitle>{{ $t("app.admin.settings.general.title") }}</DashboardTitle>
    </DashboardHeader>
    <SettingsBody>
      <template v-if="generalSettingsFetch.hasErrors">
        <ErrorState />
      </template>
      <template v-else>
        <FormGroup
          :is-loading="generalSettingsFetch.isFetching"
          @submit="submit"
        >
          <AlertError v-if="form.errors && form.errors?.unknown">
            {{ form.errors.unknown }}
          </AlertError>
          <FormSection>
            <FormInput
              id="name"
              :errors="form.errors.name"
            >
              <FormLabel>{{ $t("app.admin.settings.general.form.name") }}</FormLabel>
              <FormText
                v-model="form.values.name"
                name="name"
                required
                type="text"
              />
            </FormInput>
            <FormInput
              id="url"
              :errors="form.errors.url"
            >
              <FormLabel>{{ $t("app.admin.settings.general.form.url") }}</FormLabel>
              <FormText
                v-model="form.values.url"
                name="url"
                required
                type="url"
              />
            </FormInput>
          </FormSection>
          <div>
            <FormSubmit
              :processing="form.isFetching"
              class="btn btn-black"
            >
              {{ $t("app.admin.settings.submit") }}
            </FormSubmit>
          </div>
        </FormGroup>
      </template>
    </SettingsBody>
  </AdminLayout>
</template>

<script lang="ts" setup>
import DashboardHeader from "@/js/contexts/shared/ui/components/dashboard/DashboardHeader.vue";
import DashboardTitle from "@/js/contexts/shared/ui/components/dashboard/DashboardTitle.vue";
import AdminLayout from "@/js/contexts/admin/shared/ui/layouts/AdminLayout.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import SettingsBody from "@/js/contexts/admin/settings/ui/components/SettingsBody.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import ErrorState from "@/js/contexts/shared/ui/components/error/ErrorState.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";

type Response = { name: string; url: string };

const { t } = useI18n();
const { successNotification } = useNotification();

useHead({
  title: t("app.admin.settings.general.title"),
});

const generalSettingsFetch = useFetch("/api/admin/settings/general", { isFetching: true });

const form = useForm({
  name: "",
  url: "",
});

onMounted(() => {
  generalSettingsFetch.get<Response>().then((response) => {
    form.values.name = response.data.name;
    form.values.url = response.data.url;
    form.updatedValues();
  });
});

const submit = () => {
  form.post("/api/admin/settings/general", {
    onSuccess: () => successNotification(t("app.admin.settings.success")),
  });
};
</script>
